---
title: <span class="badge builder"></span> ElasticsearchDateHistogramSettings
---
# <span class="badge builder"></span> ElasticsearchDateHistogramSettings

## Constructor

```python
ElasticsearchDateHistogramSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchDateHistogramSettings
```

### <span class="badge object-method"></span> interval

```python
def interval(interval: str) -> typing.Self
```

### <span class="badge object-method"></span> min_doc_count

```python
def min_doc_count(min_doc_count: str) -> typing.Self
```

### <span class="badge object-method"></span> offset

```python
def offset(offset: str) -> typing.Self
```

### <span class="badge object-method"></span> time_zone

```python
def time_zone(time_zone: str) -> typing.Self
```

### <span class="badge object-method"></span> trim_edges

```python
def trim_edges(trim_edges: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchDateHistogramSettings](./object-ElasticsearchDateHistogramSettings.md)
